MapController class

Готовая к показу карта вместе с рендерером и распознавателем жестов.

Implemented types
Available extensions

Constructors

MapController.fromMessage(ClassMessage<MapController> message)
factory

Properties

gestureRecognizer → MapGestureRecognizer
Распознаватель жестов карты.
no setter
hashCode int
The hash code for this object.
no setteroverride
map Map
Карта, управляемая этим контроллером.
no setter
renderer → MapRenderer
Рендерер карты.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

message() ClassMessage<MapController>

Available on MapController, provided by the MapControllerToClassMessage extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

create(Context context, MapControllerOptions options) → CancelableOperation<MapController>
Создаёт карту с параметрами из options.