MapControllerOptions class
Constructors
-
MapControllerOptions({CameraPosition? position = null, List<
Source> sources = const [], Map<String, AttributeValue> attributes = const {}, double? fontIconSizeMultiplier = null, GraphicsPreset? graphicsPreset = null, Fps? maxFps = null, Fps? powerSavingMaxFps = null}) -
const
Properties
-
attributes
→ Map<
String, AttributeValue> -
Атрибуты карты, применяемые при создании.
final
- fontIconSizeMultiplier → double?
-
Множитель размера иконок и шрифтов. Не задано: множитель не применяется.
final
- graphicsPreset → GraphicsPreset?
-
Графический пресет качества. Не задано: пресет по умолчанию.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxFps → Fps?
-
Ограничение частоты кадров. Не задано: ограничения нет.
final
- position → CameraPosition?
-
Начальная позиция камеры. Не задано: позиция по умолчанию.
final
- powerSavingMaxFps → Fps?
-
Ограничение частоты кадров в режиме энергосбережения. Не задано: ограничения нет.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
→ List<
Source> -
Источники данных, добавляемые на карту при создании.
final
Methods
-
copyWith(
{Optional< CameraPosition?> ? position, List<Source> ? sources, Map<String, AttributeValue> ? attributes, Optional<double?> ? fontIconSizeMultiplier, Optional<GraphicsPreset?> ? graphicsPreset, Optional<Fps?> ? maxFps, Optional<Fps?> ? powerSavingMaxFps}) → MapControllerOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override